pub enum AegisError {
Show 37 variants
Storage(String),
BlockNotFound(u64),
PageNotFound(u64),
Corruption(String),
Transaction(String),
TransactionAborted(String),
Deadlock,
LockTimeout,
SerializationFailure,
Parse(String),
TypeError(String),
Execution(String),
TableNotFound(String),
ColumnNotFound(String),
IndexNotFound(String),
ConstraintViolation(String),
UniqueViolation(String),
ForeignKeyViolation(String),
CheckViolation(String),
Replication(String),
NodeNotFound(String),
QuorumNotReached,
LeaderNotElected,
AuthenticationFailed(String),
AuthorizationDenied(String),
Io(Error),
Serialization(String),
Encryption(String),
Configuration(String),
Internal(String),
ResourceExhausted(String),
MemoryLimitExceeded,
Network(String),
ConnectionRefused(String),
Timeout(String),
Vault(String),
Shield(String),
}Expand description
Unified error type for all Aegis operations.
Variants
Storage(String)
BlockNotFound(u64)
PageNotFound(u64)
Corruption(String)
Transaction(String)
TransactionAborted(String)
Deadlock
LockTimeout
SerializationFailure
Parse(String)
TypeError(String)
Execution(String)
TableNotFound(String)
ColumnNotFound(String)
IndexNotFound(String)
ConstraintViolation(String)
UniqueViolation(String)
ForeignKeyViolation(String)
CheckViolation(String)
Replication(String)
NodeNotFound(String)
QuorumNotReached
LeaderNotElected
AuthenticationFailed(String)
AuthorizationDenied(String)
Io(Error)
Serialization(String)
Encryption(String)
Configuration(String)
Internal(String)
ResourceExhausted(String)
MemoryLimitExceeded
Network(String)
ConnectionRefused(String)
Timeout(String)
Vault(String)
Shield(String)
Implementations
Sourceimpl AegisError
impl AegisError
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Returns true if the operation can be safely retried.
Sourcepub fn is_user_error(&self) -> bool
pub fn is_user_error(&self) -> bool
Returns true if this is a user error (vs system error).
Sourcepub fn is_system_error(&self) -> bool
pub fn is_system_error(&self) -> bool
Returns true if this is a system/internal error.
Sourcepub fn is_constraint_error(&self) -> bool
pub fn is_constraint_error(&self) -> bool
Returns true if this is a constraint violation error.